==> 0.29.0.tar.gz: lib/component_styles.dart <==
part of facio_styles;

class AlertStyles {
  AlertStyles._();

  /// Margin Right for Icon
  static const iconMarginRight = 8.00;

  /// Border Radius for Alert
  static const borderRadius = 8.00;

  /// Margin Bottom for Alert
  static const marginBottom = 24.00;

  /// Margin Left for Alert
  static const marginLeft = 16.00;

  /// Margin Right for Alert
  static const marginRight = 16.00;

  /// Margin Top for Alert
  static const marginTop = 4.00;

  /// Background Color for Standard Info
  static const standardInfoBackgroundColor = const Color(0xFFB3CCFF);

  /// Background Color for Standard Brand
  static const standardBrandBackgroundColor = const Color(0xFF3FE1B6);
}

class AppBarStyles {
  AppBarStyles._();

  /// Background Color for Color Default
  static const colorDefaultBackgroundColor = const Color(0xFFF2F2F3);
}

class ButtonStyles {
  ButtonStyles._();

  /// Max Width for Button
  static const maxWidth = 600;

  /// Border Radius for Full Width
  static const fullWidthBorderRadius = 8.00;

  /// Default button font size can vary depending on platform.
  static const labelFontSize = 14.00;

  /// Medium button labels have semi bold font weight
  static const labelFontWeight = FontWeight.w600;

  /// Height for Size Small
  static const sizeSmallHeight = 32.00;

  /// Padding Bottom for Size Small
  static const sizeSmallPaddingBottom = 4.00;

  /// All small buttons have left padding equivalent to 4 logical pixels
  static const sizeSmallPaddingLeft = 12.00;

  /// All small buttons have right padding equivalent to 4 logical pixels
  static const sizeSmallPaddingRight = 12.00;

  /// Padding Top for Size Small
  static const sizeSmallPaddingTop = 4.00;

  /// Height for Size Medium
  static const sizeMediumHeight = 48.00;

  /// Padding Bottom for Size Medium
  static const sizeMediumPaddingBottom = 12.00;

  /// Padding Top for Size Medium
  static const sizeMediumPaddingTop = 12.00;
}

class CardContentStyles {
  CardContentStyles._();

  /// Padding for Card Content
  static const padding = 16.00;
}

class CardStyles {
  CardStyles._();

  /// Background Color for Card
  static const backgroundColor = const Color(0xFFFAFAFA);

  /// Border Radius for Card
  static const borderRadius = 8.00;

  /// Color for Card
  static const color = const Color(0xFF424D5C);

  /// Margin Bottom for Card
  static const marginBottom = 16.00;

  /// Margin Top for Card
  static const marginTop = 0.00;
}

class CheckboxStyles {
  CheckboxStyles._();

  /// Color for Checkbox
  static const color = const Color(0xFF828C9B);

  /// Color for Checked
  static const checkedColor = const Color(0xFF424D5C);

  /// Color for Disabled
  static const disabledColor = const Color(0xFFAFB4BB);
}

class ChipStyles {
  ChipStyles._();

  /// Border Radius for Chip
  static const borderRadius = 24.00;

  /// Border Width for Chip
  static const borderWidth = 1.00;

  /// Height for Chip
  static const height = 32.00;
}

class CircularProgressStyles {
  CircularProgressStyles._();

  /// Color for Color Primary
  static const colorPrimaryColor = const Color(0xFF2BC4A8);
}

class ContainedButtonStyles {
  ContainedButtonStyles._();

  /// Border Width for Contained Button
  static const borderWidth = 0.00;

  /// Box Shadow for Hover
  static const hoverBoxShadow = Color(0xFFD1D3D6);

  /// Background Color for Brand
  static const brandBackgroundColor = const Color(0xFF3FE1B6);

  /// Color for Brand
  static const brandColor = const Color(0xFF424D5C);

  /// Background Color for Brand Hover
  static const brandHoverBackgroundColor = const Color(0xFF3FE1B6);

  /// Color for Brand Hover
  static const brandHoverColor = const Color(0xFF424D5C);

  /// Background Color for Brand Pressed
  static const brandPressedBackgroundColor = const Color(0xFF2BC4A8);

  /// Color for Brand Pressed
  static const brandPressedColor = const Color(0xFF424D5C);

  /// Background Color for Danger
  static const dangerBackgroundColor = const Color(0xFFE13F6A);

  /// Color for Danger
  static const dangerColor = const Color(0xFFFFFFFF);

  /// Background Color for Danger Hover
  static const dangerHoverBackgroundColor = const Color(0xFFE13F6A);

  /// Color for Danger Hover
  static const dangerHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Danger Pressed
  static const dangerPressedBackgroundColor = const Color(0xFFC42B47);

  /// Color for Danger Pressed
  static const dangerPressedColor = const Color(0xFFFFFFFF);

  /// Background Color for Default
  static const defaultBackgroundColor = const Color(0xFF424D5C);

  /// Color for Default
  static const defaultColor = const Color(0xFFFFFFFF);

  /// Background Color for Default Hover
  static const defaultHoverBackgroundColor = const Color(0xFF424D5C);

  /// Color for Default Hover
  static const defaultHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Default Pressed
  static const defaultPressedBackgroundColor = const Color(0xFF303846);

  /// Color for Default Pressed
  static const defaultPressedColor = const Color(0xFFFFFFFF);

  /// Border Radius for Size Medium
  static const sizeMediumBorderRadius = 24.00;

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 24.00;

  /// Background Color for Warning
  static const warningBackgroundColor = const Color(0xFFE1B63F);

  /// Color for Warning
  static const warningColor = const Color(0xFFFFFFFF);

  /// Background Color for Warning Hover
  static const warningHoverBackgroundColor = const Color(0xFFE1B63F);

  /// Color for Warning Hover
  static const warningHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Warning Pressed
  static const warningPressedBackgroundColor = const Color(0xFFC4A82B);

  /// Color for Warning Pressed
  static const warningPressedColor = const Color(0xFFFFFFFF);
}

class InputBaseStyles {
  InputBaseStyles._();

  /// Color for Input Base
  static const color = const Color(0xFF424D5C);

  /// Font size is the same of headline, formerly headline.
  static const mediumFontSize = 17.00;

  /// Font size is the same of headline2, formerly title1.
  static const largeFontSize = 28.00;
}

class LabelStyles {
  LabelStyles._();

  /// Font size is the same of subtitle1, formerly subhead.
  static const largeFontSize = 15.00;

  /// Font size is the same of caption.
  static const mediumFontSize = 12.00;
}

class LinkButtonStyles {
  LinkButtonStyles._();

  /// Color for Default
  static const defaultColor = const Color(0xFF068589);

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 8.00;
}

class OutlinedButtonStyles {
  OutlinedButtonStyles._();

  /// Border Width for Outlined Button
  static const borderWidth = 1.00;

  /// Border Color for Default
  static const defaultBorderColor = Color(0xFFE2E3E4);

  /// Color for Default
  static const defaultColor = const Color(0xFF424D5C);

  /// Color for Disabled
  static const disabledColor = const Color(0xFFAFB4BB);

  /// Border Color for Pressed
  static const pressedBorderColor = Color(0xFF2BC4A8);

  /// Color for Pressed
  static const pressedColor = const Color(0xFF424D5C);

  /// Border Color for Hover
  static const hoverBorderColor = Color(0xFF3FE1B6);

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 24.00;

  /// Padding Bottom for Size Small
  static const sizeSmallPaddingBottom = 2.00;

  /// Padding Top for Size Small
  static const sizeSmallPaddingTop = 2.00;

  /// Border Radius for Size Medium
  static const sizeMediumBorderRadius = 8.00;
}

class PaperStyles {
  PaperStyles._();

  /// Background Color for Paper
  static const backgroundColor = const Color(0xFFFAFAFA);

  /// Color for Paper
  static const color = const Color(0xFF424D5C);

  /// Border Radius for Rounded
  static const roundedBorderRadius = 8.00;

  /// Border Radius for Square
  static const squareBorderRadius = 0.00;
}

class RefreshIndicatorStyles {
  RefreshIndicatorStyles._();

  /// Padding Top for Refresh Indicator
  static const paddingTop = 0.00;

  /// Displacement for Is Loading
  static const isLoadingDisplacement = 8.00;

  /// Padding Top for Is Loading
  static const isLoadingPaddingTop = 40.00;
}

==> 0.32.4.tar.gz: lib/component_styles.dart <==
part of facio_styles;

class AlertStyles {
  AlertStyles._();

  /// Margin Right for Icon
  static const iconMarginRight = 8.00;

  /// Border Radius for Alert
  static const borderRadius = 8.00;

  /// Margin Bottom for Alert
  static const marginBottom = 24.00;

  /// Margin Left for Alert
  static const marginLeft = 16.00;

  /// Margin Right for Alert
  static const marginRight = 16.00;

  /// Margin Top for Alert
  static const marginTop = 4.00;

  /// Background Color for Standard Info
  static const standardInfoBackgroundColor = const Color(0xFFB3CCFF);

  /// Background Color for Standard Brand
  static const standardBrandBackgroundColor = const Color(0xFF3FE1B6);
}

class AppBarStyles {
  AppBarStyles._();

  /// Background Color for Color Default
  static const colorDefaultBackgroundColor = const Color(0xFFFAFAFA);
}

class ButtonStyles {
  ButtonStyles._();

  /// Max Width for Button
  static const maxWidth = 248.00;

  /// Min Width for Button
  static const minWidth = 64.00;

  /// Border Radius for Full Width
  static const fullWidthBorderRadius = 8.00;

  /// Default button font size can vary depending on platform.
  static const labelFontSize = 14.00;

  /// Medium button labels have semi bold font weight
  static const labelFontWeight = FontWeight.w600;

  /// Height for Size Small
  static const sizeSmallHeight = 32.00;

  /// Padding Bottom for Size Small
  static const sizeSmallPaddingBottom = 4.00;

  /// All small buttons have left padding equivalent to 4 logical pixels
  static const sizeSmallPaddingLeft = 12.00;

  /// All small buttons have right padding equivalent to 4 logical pixels
  static const sizeSmallPaddingRight = 12.00;

  /// Padding Top for Size Small
  static const sizeSmallPaddingTop = 4.00;

  /// Height for Size Medium
  static const sizeMediumHeight = 48.00;

  /// Padding Bottom for Size Medium
  static const sizeMediumPaddingBottom = 12.00;

  /// Padding Top for Size Medium
  static const sizeMediumPaddingTop = 12.00;
}

class CardContentStyles {
  CardContentStyles._();

  /// Padding for Card Content
  static const padding = 16.00;
}

class CardStyles {
  CardStyles._();

  /// Background Color for Card
  static const backgroundColor = const Color(0xFFFAFAFA);

  /// Border Radius for Card
  static const borderRadius = 8.00;

  /// Color for Card
  static const color = const Color(0xFF424D5C);

  /// Margin Bottom for Card
  static const marginBottom = 16.00;

  /// Margin Top for Card
  static const marginTop = 0.00;
}

class CheckboxStyles {
  CheckboxStyles._();

  /// Color for Checkbox
  static const color = const Color(0xFF828C9B);

  /// Color for Checked
  static const checkedColor = const Color(0xFF424D5C);

  /// Color for Disabled
  static const disabledColor = const Color(0xFFAFB4BB);
}

class ChipStyles {
  ChipStyles._();

  /// Border Radius for Chip
  static const borderRadius = 24.00;

  /// Border Width for Chip
  static const borderWidth = 1.00;

  /// Height for Chip
  static const height = 32.00;
}

class CircularProgressStyles {
  CircularProgressStyles._();

  /// Color for Color Primary
  static const colorPrimaryColor = const Color(0xFF2BC4A8);
}

class ContainedButtonStyles {
  ContainedButtonStyles._();

  /// Border Width for Contained Button
  static const borderWidth = 0.00;

  /// Box Shadow for Hover
  static const hoverBoxShadow = Color(0xFFD1D3D6);

  /// Background Color for Brand
  static const brandBackgroundColor = const Color(0xFF3FE1B6);

  /// Color for Brand
  static const brandColor = const Color(0xFF424D5C);

  /// Background Color for Brand Disabled
  static const brandDisabledBackgroundColor = const Color(0xFFD0FFEF);

  /// Todo: check if we will use grey.50 or grey.60
  static const brandDisabledColor = const Color(0xFFAFB4BB);

  /// Background Color for Brand Hover
  static const brandHoverBackgroundColor = const Color(0xFF3FE1B6);

  /// Color for Brand Hover
  static const brandHoverColor = const Color(0xFF424D5C);

  /// Background Color for Brand Pressed
  static const brandPressedBackgroundColor = const Color(0xFF2BC4A8);

  /// Color for Brand Pressed
  static const brandPressedColor = const Color(0xFF424D5C);

  /// Background Color for Danger
  static const dangerBackgroundColor = const Color(0xFFE13F6A);

  /// Color for Danger
  static const dangerColor = const Color(0xFFFFFFFF);

  /// Background Color for Danger Hover
  static const dangerHoverBackgroundColor = const Color(0xFFE13F6A);

  /// Color for Danger Hover
  static const dangerHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Danger Pressed
  static const dangerPressedBackgroundColor = const Color(0xFFC42B47);

  /// Color for Danger Pressed
  static const dangerPressedColor = const Color(0xFFFFFFFF);

  /// Background Color for Default
  static const defaultBackgroundColor = const Color(0xFF424D5C);

  /// Color for Default
  static const defaultColor = const Color(0xFFFFFFFF);

  /// Background Color for Default Hover
  static const defaultHoverBackgroundColor = const Color(0xFF424D5C);

  /// Color for Default Hover
  static const defaultHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Default Pressed
  static const defaultPressedBackgroundColor = const Color(0xFF303846);

  /// Color for Default Pressed
  static const defaultPressedColor = const Color(0xFFFFFFFF);

  /// Border Radius for Size Medium
  static const sizeMediumBorderRadius = 24.00;

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 24.00;

  /// Background Color for Warning
  static const warningBackgroundColor = const Color(0xFFE1B63F);

  /// Color for Warning
  static const warningColor = const Color(0xFFFFFFFF);

  /// Background Color for Warning Hover
  static const warningHoverBackgroundColor = const Color(0xFFE1B63F);

  /// Color for Warning Hover
  static const warningHoverColor = const Color(0xFFFFFFFF);

  /// Background Color for Warning Pressed
  static const warningPressedBackgroundColor = const Color(0xFFC4A82B);

  /// Color for Warning Pressed
  static const warningPressedColor = const Color(0xFFFFFFFF);
}

class CurrencyStyles {
  CurrencyStyles._();

  /// Font Weight for Currency
  static const fontWeight = FontWeight.w800;
}

class FilledInputStyles {
  FilledInputStyles._();

  /// Background Color for Filled Input
  static const backgroundColor = const Color(0xFFF2F2F3);

  /// Border Bottom Left Radius for Filled Input
  static const borderBottomLeftRadius = 8.00;

  /// Border Bottom Right Radius for Filled Input
  static const borderBottomRightRadius = 8.00;

  /// Border Top Left Radius for Filled Input
  static const borderTopLeftRadius = 8.00;

  /// Border Top Right Radius for Filled Input
  static const borderTopRightRadius = 8.00;
}

class FormLabelStyles {
  FormLabelStyles._();

  /// Color for Focused
  static const focusedColor = const Color(0xFF068589);
}

class InputBaseStyles {
  InputBaseStyles._();

  /// Color for Input Base
  static const color = const Color(0xFF424D5C);

  /// Color for Placeholder
  static const placeholderColor = const Color(0xFFAFB4BB);

  /// Opacity for Placeholder
  static const placeholderOpacity = 1;

  /// Font size is the same of headline, formerly headline.
  static const mediumFontSize = 17.00;

  /// Font size is the same of headline2, formerly title1.
  static const largeFontSize = 28.00;
}

class LabelStyles {
  LabelStyles._();

  /// Font size is the same of subtitle1, formerly subhead.
  static const largeFontSize = 15.00;

  /// Font size is the same of caption.
  static const mediumFontSize = 12.00;
}

class LinkButtonStyles {
  LinkButtonStyles._();

  /// Color for Default
  static const defaultColor = const Color(0xFF068589);

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 8.00;
}

class OutlinedButtonStyles {
  OutlinedButtonStyles._();

  /// Border Width for Outlined Button
  static const borderWidth = 1.00;

  /// Border Color for Default
  static const defaultBorderColor = Color(0xFFE2E3E4);

  /// Color for Default
  static const defaultColor = const Color(0xFF424D5C);

  /// Color for Disabled
  static const disabledColor = const Color(0xFFAFB4BB);

  /// Border Color for Pressed
  static const pressedBorderColor = Color(0xFF2BC4A8);

  /// Color for Pressed
  static const pressedColor = const Color(0xFF424D5C);

  /// Border Color for Hover
  static const hoverBorderColor = Color(0xFF3FE1B6);

  /// Border Radius for Size Small
  static const sizeSmallBorderRadius = 24.00;

  /// Padding Bottom for Size Small
  static const sizeSmallPaddingBottom = 2.00;

  /// Padding Top for Size Small
  static const sizeSmallPaddingTop = 2.00;

  /// Border Radius for Size Medium
  static const sizeMediumBorderRadius = 8.00;
}

class PaperStyles {
  PaperStyles._();

  /// Background Color for Paper
  static const backgroundColor = const Color(0xFFFAFAFA);

  /// Color for Paper
  static const color = const Color(0xFF424D5C);

  /// Border Radius for Rounded
  static const roundedBorderRadius = 8.00;

  /// Border Radius for Square
  static const squareBorderRadius = 0.00;
}

class RefreshIndicatorStyles {
  RefreshIndicatorStyles._();

  /// Padding Top for Refresh Indicator
  static const paddingTop = 0.00;

  /// Displacement for Is Loading
  static const isLoadingDisplacement = 8.00;

  /// Padding Top for Is Loading
  static const isLoadingPaddingTop = 40.00;
}
